<template>
  <div
    :class="{
      'market-editor': (this.$route.name === 'marketedit'),
      'parts-editor': (this.$route.name === 'parts_and_serviceedit'),
      'shop-editor': (!this.$route.name.includes('parts_and_service')),
      'investment-editor': (this.$route.name === 'investmentedit'),
      'editor-content': (this.$route.name === 'mediacenteredit')
  }">
    <!-- could add some conditional logic based off of individual shop styling to get this view to look right. -->
    <div style="display: flex; justify-content: space-between;">
      <h1 class="edit-shop-title">Edit {{ shop.pretty_name }}</h1>
      <img
        style="background-color: white; border-radius: 25px;"
        src="/images/app_sponsor_logo.png"
        alt="Greystone Technology Logo">
    </div>
    <div class="input-group">
      <label for="layout">Layout and Color Options</label>
      <div
        class="btn-group"
        role="group">
        <button
          :class="{selected: (shop.shop_color == 1 && shop.shop_style == 1)}"
          @click="$emit('simple-one')">Option 1
        </button>
        <button
          :class="{selected: (shop.shop_color == 2 && shop.shop_style == 1)}"
          @click="$emit('simple-two')">Option 2
        </button>
        <button
          :class="{selected: (shop.shop_color == 1 && shop.shop_style == 2)}"
          @click="$emit('busy-one')" >Option 3
        </button>
        <button
          :class="{selected: (shop.shop_color == 2 && shop.shop_style == 2)}"
          @click="$emit('busy-two')" >Option 4
        </button>
      </div>
    </div>
    <div class="input-group">
      <label for="name">Change {{ shop.pretty_name }} Name:</label>
      <input
        v-model="shop.name"
        type="text"
        maxlength="25"> <br>
    </div>
    <div class="input-group">
      <label for="description">Change {{ shop.pretty_name }} Description:</label>
      <textarea
        v-model="shop.description"
        maxlength="70"
        rows="2"/>
    </div>
    <button
      id="edit-shop-save"
      @click="putShopStyles" >Save Your {{ shop.pretty_name }} Customizations</button>
  </div>
</template>

<script>
export default {
  props: {
    shop: Object
  },
  methods: {
    putShopStyles() {
      const data = {
        shop_style: this.shop.shop_style,
        shop_color: this.shop.shop_color,
        name: this.shop.name,
        description: this.shop.description
      };
      console.log(data);
      app.session.SetSession()
        .then( () => {
          app.api.Put(`${this.shop.canonical_name}/editshop/${this.shop.id}`, data)
          .then(Response => {
            console.log(Response);
            app.Message(`Your customization for ${this.shop.pretty_name} is saved.`, "success");
            this.$router.push({name: `${this.shop.canonical_name}main` });
          })
          .catch( x => app.Message(x.error, "error"));
        });
    }
  }
};
</script>

<style lang="less" scoped>
  .edit-shop-title {
    font-size: 40px;
    color: black;
  }
  .market-editor {
    .input-group {
      label {
        text-shadow: 1px 1px grey;
      }
    }
    width: 68rem;
    margin: auto;
    padding: 10rem 0;
    color: black;
    font-size: 40px;
  }
  .investment-editor {
    .input-group {
      label {
        color: white;
      }
    }
  }
  .parts-editor {
    .edit-shop-title {
      font-size: 40px;
      color: white;
    }
    .input-group {
      margin-bottom: 2.5em !important;
      label {
        display: block;
        margin-bottom: 0.5em !important;
        font-size: 24px;
        color: white;
      }
      input, textarea {
        width: 100% !important;
        padding: 0.5em 0.75em 0.4em !important;
        font-family: "Mouse Memoirs";
        font-size: 24px !important;
        line-height: 1.2;
        font-weight: normal !important;
        color: #333 !important;
        background: white;
        border: 1px solid #ddd;
        border-radius: 10px;
        box-shadow: 0.4rem 0.4rem 0.5rem rgba(0, 0, 0, 0.2) inset;
        overflow: hidden;
      }
        .btn-group {
          display: inline-flex;
          button {
            padding: 0.25em 0.75em;
            font-family: "Mouse Memoirs";
            font-size: 21px;
            background: white;
            border: 3px solid #007dcc;
            border-right: 0;
            cursor: pointer;
              &:first-of-type {
                padding-left: 0.8em;
                border-radius: 25px 0 0 25px;
              }
              &:last-of-type {
                padding-right: 0.8em;
                border-right: 3px solid #007dcc;
                border-radius: 0 25px 25px 0;
              }
              &:hover,
              &.selected {
                color: white;
                background: #007dcc;
              }
          }
        }
    }
    button#edit-shop-save {
      padding: 0.5em 1.3em;
      font-family: "Mouse Memoirs";
      font-size: 24px;
      color: white;
      background-color: #68b502;
      border: 3px solid #c3e19a;
      border-radius: 35px;
      cursor: pointer;
    }
  }
</style>
